Arca class

Constructors

Arca(List<String> subscribedTopics)

Properties

hashCode int
The hash code for this object.
no setterinherited
nunti StreamController<AbstractNuntius>
getter/setter pair
observe Stream<AbstractNuntius>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribedTopics List<String>
final

Methods

broadcast(AbstractNuntius nuntius) → void
hasSubscription(String topic) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveNuntius(AbstractNuntius nuntius) Future<void>
send(AbstractNuntius nuntius) → void
subscribeTopic(String topic) → void
toString() String
A string representation of this object.
inherited
unsubscribeTopic(String topic) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited