Distribuo class

Constructors

Distribuo()

Properties

arcae List<Arca>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

broadcast(AbstractNuntius nuntius) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerArca(Arca toAdd) → void
send(AbstractNuntius nuntius) Future<void>
toString() String
A string representation of this object.
inherited
unregisterArca(Arca toRemove) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited