AppRouter class

Constructors

AppRouter(Map<String, Widget> routes)

Properties

hashCode int
The hash code for this object.
no setterinherited
routes Map<String, Widget>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRoute(String path, Widget page) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onGenerateRoute(RouteSettings settings) Route
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited